Crate minrx

Crate minrx 

Description

High-level bindings for the MinRX regex library, by Michael J. Haertel. This crate has an API similar to BurntSushi’s excellent regex crate, but uses an engine compliant with POSIX EREs, including matching leftmost-longest derivations.

License

This is licensed to you either under the MIT license or the Apache 2.0 license, at your option. For more details on these, check out the LICENSE files in the package.

Structs

Match
A match on some haystack. It is a wrapper of std::range::Range<usize> with some convenience methods and derives.
MatchIter
An iterator over all matches on a haystack.
MatchOptions
Regex
A MinRX regex matcher. Send but not Sync.
RegexBuilder

Enums

BuildError
MatchError